from test_admin import *
from test_forms import *
from test_listeners import *
from test_managers import *
from test_models import *
from test_settings import *
from test_templatetags import *
from test_signals import *
from test_views import *
